<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type');

// 如果是OPTIONS请求，直接返回200
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// 引入数据库连接文件
require_once '../../config/database.php';

// 获取POST数据
$postData = json_decode(file_get_contents('php://input'), true);
if (!$postData) {
    $postData = $_POST;
}

$token = isset($postData['token']) ? trim($postData['token']) : '';
$kami = isset($postData['kami']) ? trim($postData['kami']) : '';

if (empty($token) || empty($kami)) {
    echo json_encode([
        'success' => false,
        'message' => '参数不完整'
    ]);
    exit;
}

try {
    // 查询用户 - 适配mac_user表
    $stmt = $conn->prepare("SELECT user_id, user_points, user_jifenlq, user_end_time, token_expire FROM mac_user WHERE user_token = ?");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        echo json_encode([
            'success' => false,
            'message' => '无效的token'
        ]);
        exit;
    }
    
    $user = $result->fetch_assoc();
    
    // 检查token是否过期
    if ($user['token_expire'] < time()) {
        echo json_encode([
            'success' => false,
            'message' => 'token已过期'
        ]);
        exit;
    }
    
    // 查询卡密 - 适配mac_cards表
    $stmt = $conn->prepare("SELECT * FROM mac_cards WHERE card_number = ? AND is_used = 0 AND (expire_time IS NULL OR expire_time > NOW())");
    $stmt->bind_param("s", $kami);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        echo json_encode([
            'success' => false,
            'message' => '卡密不存在或已被使用'
        ]);
        exit;
    }
    
    $card = $result->fetch_assoc();
    
    // 开始事务
    $conn->begin_transaction();
    
    try {
        // 标记卡密为已使用
        $stmt = $conn->prepare("UPDATE mac_cards SET is_used = 1 WHERE id = ?");
        $stmt->bind_param("i", $card['id']);
        $stmt->execute();
        
        // 根据卡密类型更新用户信息
        if ($card['type'] === 'integral') {
            // 积分卡密
            $plog_type = 1;
            $plog_points = $card['value'];
            $plog_time = time();
            $plog_remarks = "卡密兑换积分";
            
            // 添加积分记录
            $stmt = $conn->prepare("INSERT INTO mac_plog (user_id, plog_type, plog_points, plog_time, plog_remarks) VALUES (?, ?, ?, ?, ?)");
            $stmt->bind_param("iisis", $user['user_id'], $plog_type, $plog_points, $plog_time, $plog_remarks);
            $stmt->execute();
            
            // 更新用户积分
            $stmt = $conn->prepare("UPDATE mac_user SET user_points = user_points + ? WHERE user_id = ?");
            $stmt->bind_param("ii", $card['value'], $user['user_id']);
            $stmt->execute();
            
            $newPoints = $user['user_points'] + $card['value'];
            
            $message = "成功充值{$card['value']}积分";
            $responseData = [
                'success' => true,
                'message' => $message,
                'type' => 'integral',
                'newPoints' => $newPoints
            ];
        } else if ($card['type'] === 'vip') {
            // VIP卡密
            // 更新用户VIP到期时间
            $stmt = $conn->prepare("
                UPDATE mac_user 
                SET user_end_time = UNIX_TIMESTAMP(
                    CASE 
                        WHEN user_end_time = 0 THEN DATE_ADD(NOW(), INTERVAL ? DAY)
                        ELSE DATE_ADD(FROM_UNIXTIME(user_end_time), INTERVAL ? DAY)
                    END
                ),
                group_id = 3
                WHERE user_id = ?
            ");
            $stmt->bind_param("iii", $card['value'], $card['value'], $user['user_id']);
            $stmt->execute();
            
            // 获取新的到期时间
            $stmt = $conn->prepare("SELECT user_end_time FROM mac_user WHERE user_id = ?");
            $stmt->bind_param("i", $user['user_id']);
            $stmt->execute();
            $result = $stmt->get_result();
            $updatedUser = $result->fetch_assoc();
            
            $message = "成功增加{$card['value']}天VIP时长";
            $responseData = [
                'success' => true,
                'message' => $message,
                'type' => 'vip',
                'newEndTime' => $updatedUser['user_end_time']
            ];
        } else {
            throw new Exception("未知的卡密类型");
        }
        
        // 提交事务
        $conn->commit();
        
        echo json_encode($responseData);
        
    } catch (Exception $e) {
        // 回滚事务
        $conn->rollback();
        throw $e;
    }
    
} catch (Exception $e) {
    echo json_encode([
        'success' => false,
        'message' => '使用卡密失败: ' . $e->getMessage()
    ]);
}
?>