// 广告配置服务
const adConfigService = {
  // 广告配置缓存
  config: null,
  
  // 缓存过期时间（毫秒）
  cacheExpireTime: 5 * 60 * 1000, // 5分钟
  
  // 最后更新时间
  lastUpdateTime: 0,
  
  // 获取广告配置
  async getAdConfig() {
    const now = Date.now();
    
    // 如果缓存有效，直接返回缓存
    if (this.config && (now - this.lastUpdateTime < this.cacheExpireTime)) {
      return this.config;
    }
    
    try {
      // 从服务器获取最新配置
      const app = getApp();
      // 确保使用正确的API基础URL
      const apiBaseUrl = app.globalData.apiBaseUrl || 'https://fk.ariesc.cn/';
      
      console.log('正在请求广告配置，API地址:', `${apiBaseUrl}api/ad_config.php`);
      
      const res = await new Promise((resolve, reject) => {
        wx.request({
          url: `${apiBaseUrl}api/ad_config.php`,
          method: 'GET',
          timeout: 10000, // 增加超时时间
          header: {
            'content-type': 'application/json'
          },
          success: (res) => {
            console.log('广告配置API响应:', res);
            resolve(res);
          },
          fail: (err) => {
            console.error('广告配置API请求失败:', err);
            reject(err);
          }
        });
      });
      
      if (res.statusCode === 200 && res.data && res.data.code === 0) {
        this.config = res.data.data;
        this.lastUpdateTime = now;
        
        // 同时缓存到本地，作为离线备份
        wx.setStorage({
          key: 'adConfig',
          data: {
            config: this.config,
            timestamp: now
          }
        });
        
        console.log('成功获取广告配置:', this.config);
        return this.config;
      } else {
        console.error('广告配置API返回错误状态:', res.statusCode, res.data);
        throw new Error('获取广告配置失败: ' + (res.data ? JSON.stringify(res.data) : '未知错误'));
      }
    } catch (error) {
      console.error('获取广告配置出错详情:', error);
      
      // 尝试从本地缓存获取
      try {
        const localCache = wx.getStorageSync('adConfig');
        if (localCache && localCache.config) {
          console.log('使用本地缓存的广告配置');
          this.config = localCache.config;
          this.lastUpdateTime = localCache.timestamp;
          return this.config;
        }
      } catch (e) {
        console.error('读取本地广告配置失败:', e);
      }
      
      // 返回默认配置（激励视频广告开启）
      console.log('使用默认广告配置');
      return {
        rewarded: { 
          enabled: true, 
          adUnitId: 'adunit-6a659d5afcd9ca0a' // 使用原始硬编码的广告ID作为默认值
        }
      };
    }
  },
  
  // 检查特定类型广告是否启用
  async isAdEnabled(adType) {
    try {
      const config = await this.getAdConfig();
      return config[adType] && config[adType].enabled;
    } catch (error) {
      console.error(`检查广告类型 ${adType} 是否启用时出错:`, error);
      // 出错时默认开启广告（与原始行为一致）
      return true;
    }
  },
  
  // 获取广告单元ID
  async getAdUnitId(adType) {
    try {
      const config = await this.getAdConfig();
      return (config[adType] && config[adType].enabled) ? config[adType].adUnitId : '';
    } catch (error) {
      console.error(`获取广告类型 ${adType} 的单元ID时出错:`, error);
      // 出错时返回默认广告ID
      return adType === 'rewarded' ? 'adunit-6a659d5afcd9ca0a' : '';
    }
  }
};

module.exports = adConfigService;